@@ -37,6 +37,13 @@ distNodes<-function(tree,node=NULL,clus=0.5){
   #require(doParallel)
   #require(parallel)
 
+  if(!identical(tree$tip.label,tips(tree,(Ntip(tree)+1)))){
+    data.frame(tree$tip.label,N=seq(1,Ntip(tree)))->dftips
+    tree$tip.label<-tips(tree,(Ntip(tree)+1))
+    data.frame(dftips,Nor=match(dftips[,1],tree$tip.label))->dftips
+    tree$edge[match(dftips[,2],tree$edge[,2]),2]<-dftips[,3]
+  }
+
   makeL(tree)->L
   makeL1(tree)->L1
   colnames(L)->nam
